"""
Path     addons/source-python/packages/custom/k2tools/misc.py
Name     Miscellaneous Functions and Classes
Version  1.00.000
Revision $Rev: 27 $
Author   (C) [#OMEGA] - K2


INFO

Miscellaneous functions and classes that do not fit into other categories.
Generally all methods here can be subject to change or be moved into specific
python modules.


AGREEMENT

See k2tools_license.txt
"""

__all__ = ['console_message', 'get_team_color', 'get_player', 'get_maxplayers']
__version__ = '1.00.000 $Rev: 27 $'
__author__ = '[#OMEGA] - K2'
__date__ = '$Date: 2013-09-12 17:03:16 +0200 (Do, 12 Sep 2013) $'

# =============================================================================
# >> Imports
# =============================================================================

# k2tools
from ._shared import cfg as _cfg

# Source Python
from player_c import CPlayerGenerator
from entity_c import CEntityGenerator

from core import GameEngine
from entities.helpers import index_from_edict

# =============================================================================
# >> Methods
# =============================================================================

def console_message(message):
    """
    Sends a message to console. If logging is enabled, it will be logged, otherwise it will just print out.
    
    @message - message to print
    """
    if GameEngine.is_log_enabled():
        GameEngine.log_print(message + '\n')
    else:
        print (message)

def get_team_color(teamid):
    """
    Returns a color code for the given teamid depending on the specific game. 
    
    @teamid - ID of the team
    
    @return str the color code
    """
    return _cfg['Colors']['Team%s' % teamid]

def get_player(string=''):
    """
    Finds the first CPlayerInfo instance for the specified search string.
    
    Resolution order:
    - UserID
    - SteamID
    - Exact Name
    - Partial Name
    
    @string - Search string
    
    @return CPlayerInfo on success
    @return None on failure
    """
    # Empty string; return first player
    if not string:
        for player in CPlayerGenerator():
            return player
        return None
    
    if string.isdigit():
        id = int(string)
        # Matching userid
        for player in CPlayerGenerator():
            if player.get_userid() == id:
                return player
    # Matching SteamID
    for player in CPlayerGenerator():
        if player.get_networkid_string() == string:
            return player
    # Matching Name (exact)
    for player in CPlayerGenerator():
        if player.get_name() == string:
            return player
    # Matching Name (partial)
    for player in CPlayerGenerator():
        if string in player.get_name():
            return player
    # Failed to find a match, return None
    return None
    
def get_maxplayers():
    """
    Calculates current maxplayers and returns it.
    
    @return int maxplayers
    """
    index = 255
    for edict in CEntityGenerator('cs_team_manager'):
        tempindex = index_from_edict(edict)
        if tempindex < index:
            index = tempindex
    return index - 1